﻿using UnityEngine;
using System.Collections;
using Barsalt.ModularParameterEditor;
using Barsalt.ParameterSystem;
using Barsalt.ModularParameterEditor.ParameterTypes;
using Assets.ParameterSystem;

public class Example : MonoBehaviour, ParameterListener {
	private ParameterEditor parameterEditor = new ParameterEditor(32, 32, "Example Archive");

	// Use this for initialization
	void Start () {
		parameterEditor.IsDragAble		= true;
		parameterEditor.IsResizeAble	= true;
	
		// delegate to the method from where the editor retrives the archive he displays
		parameterEditor.ArchiveLoader	= LoadArchive;

		// same for saving the archive
		parameterEditor.ArchiveSaver	= SaveArchive;

		// enables the editor to work with any value of the type int
		// - derives from class BaseParameterType
		// - allows implementation for working with other typs
		parameterEditor.Add(new IntParameterType());
	}
	
	public ParameterArchive LoadArchive(){
		ParameterArchive archive = new ParameterArchive();

		archive.AddGroup("first group");
		archive.AddValue("first group", "first value", 15);
		archive.AddValue("first group", "second value", 20.0);

		archive.Name = "ExampleArchive";

		// add a listener that is called when the first group is distributed
		archive.AddParameterListener("first group", this);

		return archive;
	}

	public bool SaveArchive(ParameterArchive archive){
		Debug.LogWarning("The archive is not really saved because I am to lazy! :/");

		return true;
	}

	// Update is called once per frame
	void Update () {
	
	}

	void OnGUI(){
		parameterEditor.Display();
	}

	public void OnParameterChange(ParameterEvent parameterEvent) {
		Debug.Log("GROUP[" + parameterEvent.group + "] ARCHIVE[" + parameterEvent.archive.Name + "]");

		for( int index = 0; index < parameterEvent.Count; index++ ){
			Debug.Log("KEY[" + parameterEvent[index] + "]");
		}
	}
}
