﻿using UnityEngine;
using System.Collections;

namespace Barsalt.ModularParameterEditor.EntryElements {
	/// <summary>
	/// Elements derived from the EntryElement are used by the ParameterEditor to display ParameterArchive entries and provide a GUI to manipulate them.
	/// </summary>
	public abstract class EntryElement {
		#region OBJECT_ATTRIBUTES
		//==========================================================================
		private readonly ParameterEditor.Manager MANAGER;
		private readonly string KEY;
		private readonly string GROUP;
		private object originalValue;
		//==========================================================================
		#endregion

		#region CONSTRUCTOR
		//==========================================================================
		/// <summary>
		/// 
		/// </summary>
		/// <param name="manager">The Manager is the interface for modifications to the ParameterArchive from the EntryElement, it is provided by the ParameterEditor</param>
		/// <param name="group">The key of the group the entry belongs to</param>
		/// <param name="key">The key of the entry</param>
		/// <param name="value">The value of the entry</param>
		public EntryElement(ParameterEditor.Manager manager, string group, string key, object value) {
			this.MANAGER		= manager;
			this.KEY			= key;
			this.GROUP			= group;
			this.originalValue	= value;
		}
		//==========================================================================
		#endregion

		#region OBJECT_FUNCTIONS
		//==========================================================================
		/// <summary>
		/// The function displays the EntryElement
		/// </summary>
		/// <param name="x">The x position at which the element should be displayed</param>
		/// <param name="y">The y position at which the element should be displayed</param>
		/// <param name="width">The width that the element has to be displayed</param>
		public abstract void OnGui(int x, int y, int width);
		//==========================================================================
		#endregion

		#region GETTER_AND_SETTER
		//==========================================================================
		/// <summary>
		/// The value of the ParameterArchive entry
		/// </summary>
		protected object Value{
			get{
				return originalValue;
			}
			set{
				originalValue = value;
			}
		}
	
		/// <summary>
		/// The size of the EntryElement
		/// </summary>
		public abstract int Size{
			get;
		}
	
		/// <summary>
		/// The key of the entry
		/// </summary>
		public string Key{
			get{
				return KEY;
			}
		}
	
		/// <summary>
		/// The group of the entry
		/// </summary>
		public string Group{
			get{
				return GROUP;
			}
		}

		protected ParameterEditor.Manager Manager{
			get{
				return MANAGER;
			}
		}
		//==========================================================================
		#endregion
	}
}