﻿using UnityEngine;
using System.Collections;
using System;

namespace Barsalt.ModularParameterEditor.EntryElements {
	/// <summary>
	/// The IntEntryElement displays entries that have the datatype int and provides a GUI to modifiy them.
	/// </summary>
	public class IntEntryElement : EntryElement {
		#region CLASS_ATTRIBUTES
		//==========================================================================
		private static readonly int BUTTON_WIDTH = 64;
		private static readonly int BORDER_HEIGHT = 32;
		private static readonly int ELEMENT_HEIGHT = 24;
		private static readonly int PADDING = 4;
		//==========================================================================
		#endregion
	
		#region OBJECT_ATTRIBUTES
		//==========================================================================
		private string currentValue;
		//==========================================================================
		#endregion

		#region CONSTRUCTOR
		//==========================================================================
		/// <summary>
		/// 
		/// </summary>
		/// <param name="manager">The Manager is the interface for modifications to the ParameterArchive from the IntEntryElement, it is provided by the ParameterEditor</param>
		/// <param name="group">The key of the group the entry belongs to</param>
		/// <param name="key">The key of the entry</param>
		/// <param name="value">The value of the entry</param>
		public IntEntryElement(ParameterEditor.Manager manager, string group, string key, int value) : base(manager, group, key, value) {
			currentValue = value.ToString();
		}
		//==========================================================================
		#endregion

		#region OBJECT_FUNCTIONS
		//==========================================================================
		/// <summary>
		/// The function displays the IntEntryElement
		/// </summary>
		/// <param name="x">The x position at which the element should be displayed</param>
		/// <param name="y">The y position at which the element should be displayed</param>
		/// <param name="width">The width that the element has to be displayed</param>
		public override void OnGui(int x, int y, int width) {
			int keyWidth = (int)((width - 7 * PADDING - BUTTON_WIDTH * 3) * 0.7);
			int typeWidth = (int)((width - 7 * PADDING - BUTTON_WIDTH * 3) * 0.1);
			int valueWidth = (int)((width - 7 * PADDING - BUTTON_WIDTH * 3) * 0.2);
		
			GUI.Box(new Rect(x, y, width, BORDER_HEIGHT), "");
	
			y += PADDING;
	
			if(GUI.Button(new Rect(x + PADDING, y, BUTTON_WIDTH, ELEMENT_HEIGHT), "Remove")) {
				Manager.RemoveEntry(Group, Key);
			}
	
			GUI.Box(new Rect(x + 2 * PADDING + BUTTON_WIDTH, y, keyWidth, ELEMENT_HEIGHT), Key);
	
			GUI.Box(new Rect(x + 3 * PADDING + BUTTON_WIDTH + keyWidth, y, typeWidth, ELEMENT_HEIGHT), "int");
	
			currentValue = GUI.TextField(new Rect(x + 4 * PADDING + BUTTON_WIDTH + keyWidth + typeWidth, y, valueWidth, ELEMENT_HEIGHT), currentValue);
	
			if(currentValue.Equals(Value.ToString()) || IsValid()){
				GUI.enabled = false;
			}
	
			if(GUI.Button(new Rect(x + 5 * PADDING + BUTTON_WIDTH + keyWidth + typeWidth + valueWidth, y, BUTTON_WIDTH, ELEMENT_HEIGHT), "Apply")) {
				if(Manager.UpdateEntry(Group, Key, int.Parse(currentValue))){
					Value = int.Parse(currentValue);
				}
			}
	
			GUI.enabled = true;
	
			if(currentValue.Equals(Value.ToString())) {
				GUI.enabled = false;
			}
	
			if(GUI.Button(new Rect(x + 6 * PADDING + 2* BUTTON_WIDTH + keyWidth + typeWidth + valueWidth, y, BUTTON_WIDTH, ELEMENT_HEIGHT), "Reset")) {
				currentValue = Value.ToString();
			}
	
			GUI.enabled = true;
		}
	
		private bool IsValid(){
			try{
				int.Parse(currentValue);
	
				return false;
			} catch(FormatException){
				return true;
			}
		}
		//==========================================================================
		#endregion

		#region GETTER_AND_SETTER
		//==========================================================================
		/// <summary>
		/// The size of the IntEntryElement
		/// </summary>
		public override int Size {
			get {
				return BORDER_HEIGHT;
			}
		}
		//==========================================================================
		#endregion
	}
}