﻿using UnityEngine;
using System.Collections;

namespace Barsalt.ModularParameterEditor.EntryElements {
	/// <summary>
	/// The NullEntryElement is used to display all ParameterArchive entries that have a datatype that the ParameterEditor can't process.
	/// </summary>
	public class NullEntryElement : EntryElement {
		#region CLASS_ATTRIBUTES
		//==========================================================================
		private static readonly int BUTTON_WIDTH	= 64;
		private static readonly int BORDER_HEIGHT	= 32;
		private static readonly int ELEMENT_HEIGHT	= 24;
		private static readonly int PADDING			= 4;
		//==========================================================================
		#endregion
	
		#region CONSTRUCTOR
		//==========================================================================
		/// <summary>
		/// 
		/// </summary>
		/// <param name="manager">The Manager is the interface for modifications to the ParameterArchive from the NullEntryElement, it is provided by the ParameterEditor</param>
		/// <param name="group">The key of the group the entry belongs to</param>
		/// <param name="key">The key of the entry</param>
		/// <param name="value">The value of the entry</param>
		public NullEntryElement(ParameterEditor.Manager manager, string group, string key, object value) : base(manager, group, key, value) {}
		//==========================================================================
		#endregion
	
		#region OBJECT_FUNCTIONS
		//==========================================================================
		/// <summary>
		/// The function displays the NullEntryElement
		/// </summary>
		/// <param name="x">The x position at which the element should be displayed</param>
		/// <param name="y">The y position at which the element should be displayed</param>
		/// <param name="width">The width that the element has to be displayed</param>
		public override void OnGui(int x, int y, int width) {
			int keyWidth = (int) ((width - 5 * PADDING - BUTTON_WIDTH) * 0.6);
			int typeWidth = (int) ((width - 5 * PADDING - BUTTON_WIDTH) * 0.2); 
			int valueWidth = typeWidth;
			
			GUI.Box(new Rect(x, y, width, BORDER_HEIGHT), "");

			y += PADDING;

			if(GUI.Button(new Rect(x + PADDING, y, BUTTON_WIDTH, ELEMENT_HEIGHT), "Remove")) {
				Manager.RemoveEntry(Group, Key);
			}

			GUI.Box(new Rect(x + 2 * PADDING + BUTTON_WIDTH, y, keyWidth, ELEMENT_HEIGHT), Key);
			GUI.Box(new Rect(x + 3 * PADDING + BUTTON_WIDTH + keyWidth, y, typeWidth, ELEMENT_HEIGHT), Value.GetType().Name);
			GUI.Box(new Rect(x + 4 * PADDING + BUTTON_WIDTH + keyWidth + typeWidth, y, valueWidth, ELEMENT_HEIGHT), Value.ToString());
		}
		//==========================================================================
		#endregion
		
		#region GETTER_AND_SETTER
		//==========================================================================
		/// <summary>
		/// The size of the NullEntryElement
		/// </summary>
		public override int Size {
			get {
				return BORDER_HEIGHT;
			}
		}
		//==========================================================================
		#endregion
	}
}