﻿using UnityEngine;
using System.Collections;
using System;
using Barsalt.ModularParameterEditor.EntryElements;

namespace Barsalt.ModularParameterEditor.ParameterTypes {
	/// <summary>
	/// The FloatParameterType is used in the ParameterEditor to display and manipulate entries in a ParameterArchive that have the datatype float.
	/// </summary>
	public class FloatParameterType : BaseParameterType {
		#region CONSTRUCTOR
		//==========================================================================
		public FloatParameterType() : base(typeof(float), "float") {}
		//==========================================================================
		#endregion

		#region OBJECT_FUNCTIONS
		//==========================================================================
		/// <summary>
		/// The function provides the ParameterEditor with an FloatEntryElement corresponding to its datatype.
		/// </summary>
		/// <param name="manager">The Manager that is passed from the ParameterEditor</param>
		/// <param name="group">The key of the group the EntryElement belongs to</param>
		/// <param name="key">The key of the entry in the ParameterArchive</param>
		/// <param name="value">The value of the EntryElement</param>
		/// <returns></returns>
		public override EntryElement NewEntryElement(ParameterEditor.Manager manager, string group, string key, object value) {
			return new FloatEntryElement(manager, group, key, (float) value);
		}
		//==========================================================================
		#endregion

		#region GETTER_AND_SETTER
		//==========================================================================
		/// <summary>
		/// The default value of the dataType. It is used when the editor adds a new entry into the ParameterArchive.
		/// </summary>
		public override object Default {
			get {
				return 0.0f;
			}
		}
		//==========================================================================
		#endregion
	}
}