﻿using UnityEngine;
using System.Collections;
using System;
using Barsalt.ModularParameterEditor.EntryElements;

namespace Barsalt.ModularParameterEditor.ParameterTypes {
	/// <summary>
	/// The IntParameterType is used in the ParameterEditor to display and manipulate entries in a ParameterArchive that have the datatype int.
	/// </summary>
	public class IntParameterType : BaseParameterType {
		#region CONSTRUCTOR
		//==========================================================================
		public IntParameterType() : base(typeof(int), "int") {}
		//==========================================================================
		#endregion

		#region OBJECT_FUNCTIONS
		//==========================================================================
		/// <summary>
		/// The function provides the ParameterEditor with an IntEntryElement corresponding to its datatype.
		/// </summary>
		/// <param name="manager">The Manager that is passed from the ParameterEditor</param>
		/// <param name="group">The key of the group the EntryElement belongs to</param>
		/// <param name="key">The key of the entry in the ParameterArchive</param>
		/// <param name="value">The value of the EntryElement</param>
		/// <returns></returns>
		public override EntryElement NewEntryElement(ParameterEditor.Manager manager, string group, string key, object value) {
			return new IntEntryElement(manager, group, key, (int) value);
		}
		//==========================================================================
		#endregion

		#region GETTER_AMD_SETTER
		//==========================================================================
		/// <summary>
		/// The default value of the dataType. It is used when the editor adds a new entry into the ParameterArchive.
		/// </summary>
		public override object Default {
			get {
				return 0;
			}
		}
		//==========================================================================
		#endregion
	}
}
